import React, { Component } from 'react';
import * as PropTypes from 'prop-types';
import { TableFilterRow } from '@devexpress/dx-react-grid-material-ui';

import DataTableSortControls, { SORT_DIRECTIONS } from './DataTableSortControls';
import DataTableFilterControls from './DataTableFilterControls';

class DataTableFilterCell extends Component {
    static propTypes = {
        children: PropTypes.oneOfType([
            PropTypes.array,
            PropTypes.node,
            PropTypes.element,
        ]),
        className: PropTypes.string,
        column: PropTypes.shape({
            name: PropTypes.string,
            title: PropTypes.string,
        }),
        colSpan: PropTypes.number,
        filter: PropTypes.object,
        filteringEnabled: PropTypes.bool,
        getMessage: PropTypes.func,
        onFilter: PropTypes.func,
        onFilterCancel: PropTypes.func,
        onFilterReset: PropTypes.func,
        onFilterSubmit: PropTypes.func,
        onSortAscending: PropTypes.func,
        onSortClear: PropTypes.func,
        onSortDescending: PropTypes.func,
        rowSpan: PropTypes.number,
        sortDirection: PropTypes.oneOf(Object.keys(SORT_DIRECTIONS).map((d) => SORT_DIRECTIONS[d])),
        sortOrder: PropTypes.number,
        style: PropTypes.object,
        tableColumn: PropTypes.object,
        tableRow: PropTypes.object,
    };

    shouldComponentUpdate(nextProps) {
        const {
            className,
            filter,
            sortDirection,
            sortOrder,
            style,
        } = this.props;

        if (nextProps.filter !== filter ||
            nextProps.className !== className ||
            JSON.stringify(nextProps.style) !== JSON.stringify(style) ||
            nextProps.sortDirection !== sortDirection ||
            nextProps.sortOrder !== sortOrder) {
            return true;
        }

        return false;
    }

    render() {
        console.log('DATA TABLE DXG: FILTER CELL: RENDER: ', this.props); // eslint-disable-line
        const {
            children,
            column,
            onFilterCancel,
            onFilterReset,
            onFilterSubmit,
            onSortAscending,
            onSortClear,
            onSortDescending,
            sortDirection,
            sortOrder,
            ...rest
        } = this.props;
        const {
            name,
        } = column;

        return (
            <TableFilterRow.Cell { ...rest }>
                <div style={ {
                    display: 'flex',
                    flexDirection: 'column',
                } }>
                    <DataTableSortControls
                        columnName={ name }
                        onSortAscending={ this.handleSortAscending }
                        onSortClear={ this.handleSortClear }
                        onSortDescending={ this.handleSortDescending }
                        sortDirection={ sortDirection }
                        sortOrder={ sortOrder } />
                    <div style={ {
                        display: 'flex',
                        flexDirection: 'row',
                    } }>
                        { children }
                    </div>
                    <DataTableFilterControls
                        columnName={ name }
                        onFilterCancel={ this.handleFilterCancel }
                        onFilterReset={ this.handleFilterReset }
                        onFilterSubmit={ this.handleFilterSubmit } />
                </div>
            </TableFilterRow.Cell>
        );
    }

    handleFilterCancel = () => {
        const {
            column,
            onFilterCancel,
        } = this.props;
        const {
            name,
        } = column;

        console.log('FILTER CANCEL: ', name); // eslint-disable-line

        if (onFilterCancel) {
            onFilterCancel(name);
        }
    };

    handleFilterReset = () => {
        const {
            column,
            onFilterReset,
        } = this.props;
        const {
            name,
        } = column;

        console.log('FILTER RESET: ', name); // eslint-disable-line

        if (onFilterReset) {
            onFilterReset(name);
        }
    };

    handleFilterSubmit = () => {
        const {
            column,
            onFilterSubmit,
        } = this.props;
        const {
            name,
        } = column;

        console.log('FILTER SUBMIT: ', name); // eslint-disable-line

        if (onFilterSubmit) {
            onFilterSubmit(name);
        }
    };

    handleSortAscending = () => {
        const {
            column,
            onSortAscending,
        } = this.props;
        const {
            name,
        } = column;

        console.log('SORT ASCENDING: ', name); // eslint-disable-line

        if (onSortAscending) {
            onSortAscending(name);
        }
    };

    handleSortClear = () => {
        const {
            column,
            onSortClear,
        } = this.props;
        const {
            name,
        } = column;

        console.log('SORT CLEAR: ', name); // eslint-disable-line

        if (onSortClear) {
            onSortClear(name);
        }
    };

    handleSortDescending = () => {
        const {
            column,
            onSortDescending,
        } = this.props;
        const {
            name,
        } = column;

        console.log('SORT DESCENDING: ', name); // eslint-disable-line

        if (onSortDescending) {
            onSortDescending(name);
        }
    };
}

export {
    SORT_DIRECTIONS,
};

export default DataTableFilterCell;
