import React, { PureComponent } from 'react';
import * as PropTypes from 'prop-types';

import IconButton, { ICON_SIZE } from '../IconButton/IconButton';

class DataTableFilterControls extends PureComponent {
    static propTypes = {
        columnName: PropTypes.string,
        onFilterCancel: PropTypes.func,
        onFilterReset: PropTypes.func,
        onFilterSubmit: PropTypes.func,
    };

    render() {
        console.log('DATA TABLE DXG: FILTER CONTROLS: RENDER: ', this.props); // eslint-disable-line

        return (
            <div style={ {
                display: 'flex',
                flexDirection: 'row',
            } }>
                <IconButton
                    iconName="done"
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ this.handleFilterSubmit }
                    title="apply filters" />
                <IconButton
                    iconName="undo"
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ this.handleFilterReset }
                    title="reset filters" />
                <IconButton
                    iconName="clear"
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ this.handleFilterCancel }
                    title="cancel" />
            </div>
        );
    }

    handleFilterCancel = () => {
        const {
            columnName,
            onFilterCancel,
        } = this.props;

        console.log('FILTER CANCEL: ', columnName); // eslint-disable-line

        if (onFilterCancel) {
            onFilterCancel(columnName);
        }
    };

    handleFilterReset = () => {
        const {
            columnName,
            onFilterReset,
        } = this.props;

        console.log('FILTER RESET: ', columnName); // eslint-disable-line

        if (onFilterReset) {
            onFilterReset(columnName);
        }
    };

    handleFilterSubmit = () => {
        const {
            columnName,
            onFilterSubmit,
        } = this.props;

        console.log('FILTER SUBMIT: ', columnName); // eslint-disable-line

        if (onFilterSubmit) {
            onFilterSubmit(columnName);
        }
    };
}

export default DataTableFilterControls;
