import React, { PureComponent } from 'react';
import * as PropTypes from 'prop-types';
import IconButton, { ICON_SIZE } from '../IconButton/IconButton';
import TextLabel from '../TextLabel/TextLabel';

class DataTableHeaderCell extends PureComponent {
    static propTypes = {
        columnLocked: PropTypes.bool,
        columnName: PropTypes.string.isRequired,
        columnTitle: PropTypes.string.isRequired,
        onColumnFrozen: PropTypes.func,
        onFilterToggle: PropTypes.func,
        showFilterRow: PropTypes.bool,
    };

    render() {
        console.log('DATA TABLE DXG: HEADER CELL: RENDER: ', this.props); // eslint-disable-line
        const {
            columnLocked,
            columnName,
            columnTitle,
            onColumnFrozen,
            onFilterToggle,
            showFilterRow,
        } = this.props;
        let fixedIcon = 'lock_open';
        let fixedTitle = 'lock column';
        if (columnLocked) {
            fixedIcon = 'lock';
            fixedTitle = 'unlock column';
        }
        return (
            <div
                style={ {
                    display: 'flex',
                    flexDirection: 'row',
                    alignItems: 'center',
                    overflow: 'hidden',
                } }>
                <TextLabel>
                    { columnTitle }
                </TextLabel>
                <IconButton
                    iconName="filter_list"
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ () => onFilterToggle(columnName) }
                    title={ `${ showFilterRow ? 'close' : 'open' } filter` } />
                <IconButton
                    iconName={ fixedIcon }
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ () => onColumnFrozen(columnName) }
                    title={ fixedTitle } />
            </div>
        );
    }
}

export default DataTableHeaderCell;
