import React, { PureComponent } from 'react';
import * as PropTypes from 'prop-types';

import IconButton, { ICON_SIZE } from '../IconButton/IconButton';

const SORT_DIRECTIONS = {
    ASC: 'asc',
    DESC: 'desc',
    NONE: null,
};

class DataTableSortControls extends PureComponent {
    static propTypes = {
        columnName: PropTypes.string,
        onSortAscending: PropTypes.func,
        onSortClear: PropTypes.func,
        onSortDescending: PropTypes.func,
        sortDirection: PropTypes.oneOf(Object.keys(SORT_DIRECTIONS).map((d) => SORT_DIRECTIONS[d])),
        sortOrder: PropTypes.number,
    };

    render() {
        console.log('DATA TABLE DXG: SORT CONTROLS: RENDER: ', this.props); // eslint-disable-line
        const {
            sortDirection,
            sortOrder,
        } = this.props;

        return (
            <div style={ {
                display: 'flex',
                flexDirection: 'row',
            } }>
                <IconButton
                    badgeText={ sortDirection === SORT_DIRECTIONS.ASC && sortOrder ? sortOrder.toString() : '' }
                    contextStyles={ {
                        icon: {
                            // Invert sort descending icon for sort ascending as one was not in the core library
                            transform: 'scaleY(-1)',
                        },
                    } }
                    disabled={ sortDirection === SORT_DIRECTIONS.ASC }
                    iconName="sort"
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ this.handleSortAscending }
                    title="sort ascending" />
                <IconButton
                    badgeText={ sortDirection === SORT_DIRECTIONS.DESC && sortOrder ? sortOrder.toString() : '' }
                    disabled={ sortDirection === SORT_DIRECTIONS.DESC }
                    iconName="sort"
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ this.handleSortDescending }
                    title="sort descending" />
                <IconButton
                    disabled={ !sortDirection }
                    iconName="block"
                    iconSize={ ICON_SIZE.SMALL }
                    onClick={ this.handleSortClear }
                    title="clear sort" />
            </div>
        );
    }

    handleSortAscending = () => {
        const {
            columnName,
            onSortAscending,
        } = this.props;

        console.log('SORT ASCENDING: ', columnName); // eslint-disable-line

        if (onSortAscending) {
            onSortAscending(columnName);
        }
    };

    handleSortClear = () => {
        const {
            columnName,
            onSortClear,
        } = this.props;

        console.log('SORT CLEAR: ', columnName); // eslint-disable-line

        if (onSortClear) {
            onSortClear(columnName);
        }
    };

    handleSortDescending = () => {
        const {
            columnName,
            onSortDescending,
        } = this.props;

        console.log('SORT DESCENDING: ', columnName); // eslint-disable-line

        if (onSortDescending) {
            onSortDescending(columnName);
        }
    };
}

export {
    SORT_DIRECTIONS,
};

export default DataTableSortControls;
